@@ -1047,19 +1047,40 @@ class RunManager(_BaseManager):
 
         layout = Layout(width="200px")
         buttons = [
-            Button(description="update info", layout=layout, button_color="lightgreen"),
-            Button(description="cancel jobs", layout=layout, button_style="danger"),
+            Button(
+                description="update info",
+                layout=layout,
+                button_color="lightgreen",
+                icon="refresh",
+            ),
+            Button(
+                description="cancel jobs",
+                layout=layout,
+                button_style="danger",
+                icon="stop",
+            ),
             Button(
                 description="cleanup log and batch files",
                 layout=layout,
                 button_style="danger",
+                icon="remove",
+            ),
+            Button(
+                description="load learners",
+                layout=layout,
+                button_style="info",
+                icon="download",
+            ),
+            Button(
+                description="show logs", layout=layout, button_style="info", icon="book"
             ),
-            Button(description="show logs", layout=layout, button_style="info"),
         ]
         buttons = {b.description: b for b in buttons}
 
         box = VBox([])
 
+        log_widget = None
+
         def update(_):
             status.value = self._info_html()
 
@@ -1071,17 +1092,28 @@ class RunManager(_BaseManager):
             self.cleanup()
             update(_)
 
-        def show_logs(_):
-            new_children = tuple(
-                c for c in box.children if c.description != "show logs"
-            )
-            box.children = (*new_children, log_explorer(self))
+        def load_learners(_):
+            self.load_learners()
+
+        def toggle_logs(_):
+            nonlocal log_widget
+
+            if log_widget is None:
+                log_widget = log_explorer(self)
+
+            b = buttons["show logs"]
+            if b.description == "show logs":
+                b.description = "hide logs"
+                box.children = (*box.children, log_widget)
+            else:
+                b.description = "show logs"
+                box.children = box.children[:-1]
 
         buttons["cancel jobs"].on_click(cancel)
         buttons["cleanup log and batch files"].on_click(cleanup)
         buttons["update info"].on_click(update)
-        buttons["show logs"].on_click(show_logs)
-
+        buttons["show logs"].on_click(toggle_logs)
+        buttons["load learners"].on_click(load_learners)
         box.children = (status, *tuple(buttons.values()))
         display(box)
 
