@@ -17,8 +17,13 @@ def _get_fnames(run_manager, only_running: bool) -> List[Path]:
 
 
 def _read_file(fname: Path) -> str:
-    with fname.open() as f:
-        return "".join(f.readlines())
+    try:
+        with fname.open() as f:
+            return "".join(f.readlines())
+    except UnicodeDecodeError:
+        return f"Could not decode file ({fname})!"
+    except Exception as e:
+        return f"Exception with trying to read {fname}:\n{e}."
 
 
 def log_explorer(run_manager) -> VBox:  # noqa: C901
@@ -113,5 +118,5 @@ def log_explorer(run_manager) -> VBox:  # noqa: C901
     title = HTML("<h2><tt>adaptive_scheduler.widgets.log_explorer</tt></h2>")
     return VBox(
         [title, checkbox, update_button, dropdown, tail_button, textarea],
-        layout=Layout(border="solid 2px gray", min_height="500px"),
+        layout=Layout(border="solid 2px gray"),
     )
